summaryrefslogtreecommitdiffstats
path: root/dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/LectureDetailsWindow.java
diff options
context:
space:
mode:
authorJonathan Bauer2016-01-05 14:11:28 +0100
committerJonathan Bauer2016-01-05 14:11:28 +0100
commitaf93df1939c5c319456608bdc04c09c32cbe084a (patch)
tree7e64bacc7f21a86cbfdba46bdd249a3635afe196 /dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/LectureDetailsWindow.java
parent[client] room selection widget [wip] (diff)
downloadtutor-module-af93df1939c5c319456608bdc04c09c32cbe084a.tar.gz
tutor-module-af93df1939c5c319456608bdc04c09c32cbe084a.tar.xz
tutor-module-af93df1939c5c319456608bdc04c09c32cbe084a.zip
[client] checkbox to show the lecture only in the selected rooms
functionality still wip renamed room -> locations
Diffstat (limited to 'dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/LectureDetailsWindow.java')
-rw-r--r--dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/LectureDetailsWindow.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/LectureDetailsWindow.java b/dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/LectureDetailsWindow.java
index 5118ebcf..e7a08115 100644
--- a/dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/LectureDetailsWindow.java
+++ b/dozentenmodul/src/main/java/org/openslx/dozmod/gui/window/LectureDetailsWindow.java
@@ -196,12 +196,12 @@ public class LectureDetailsWindow extends LectureDetailsWindowLayout implements
reactToChange();
}
});
- btnRooms.addActionListener(new ActionListener() {
+ btnLocations.addActionListener(new ActionListener() {
@Override
public void actionPerformed(ActionEvent e) {
- List<Integer> roomList = new ArrayList<Integer>();
- // TODO load the room list from the LectureSummary
- List<Integer> newRoomList = RoomSelectorWindow.open(me, roomList);
+ List<Integer> locationsList = new ArrayList<Integer>();
+ // TODO load the location list from the LectureSummary
+ List<Integer> newLocationsList = LocationSelectionWindow.open(me, locationsList);
// TODO check if something changed and if so save the change
}
});
@@ -477,7 +477,7 @@ public class LectureDetailsWindow extends LectureDetailsWindowLayout implements
DateTimeHelper.getDateFrom(startDate, startTime).getTime() / 1000L,
DateTimeHelper.getDateFrom(endDate, endTime).getTime() / 1000L, null, null,
chkIsExam.isSelected(), chkHasInternetAccess.isSelected(),
- lecture.getDefaultPermissions(), null);
+ lecture.getDefaultPermissions(), null, false);
// now trigger the actual action
try {
ThriftManager.getSatClient().updateLecture(Session.getSatelliteToken(),
@@ -594,7 +594,7 @@ public class LectureDetailsWindow extends LectureDetailsWindowLayout implements
lblError.setText("Ungültiger Zeitraum!");
return false;
}
// TODO check if rooms changed
// done with mandatory checks, remove error message
lblError.setText(null);
@@ -594,7 +594,7 @@ public class LectureDetailsWindow extends LectureDetailsWindowLayout implements
return false;
}
- // TODO check if rooms changed
+ // TODO check if locations changed
// done with mandatory checks, remove error message
lblError.setText(null);